@@ -18,6 +18,8 @@
 #    detalhes.
 #--------------------------------------------------------------------------
 
+from six import with_metaclass
+
 import numpy as np
 import math
 import vtk
@@ -27,14 +29,12 @@ import invesalius.utils as utils
 import invesalius.constants as const
 
 
-class Box(object):
+class Box(with_metaclass(utils.Singleton, object)):
     """
-    This class is a data structure for storing the 
+    This class is a data structure for storing the
     coordinates (min and max) of box used in crop-mask.
     """
 
-    __metaclass__= utils.Singleton
-
     def __init__(self):
         self.xi = None
         self.xf = None
@@ -136,7 +136,7 @@ class Box(object):
         self.axial[const.AXIAL_RIGHT] = [[self.xf + (self.xs/2), self.yi, self.zi],\
                                          [self.xf + (self.xs/2), self.yf, self.zf]]
 
-        Publisher.sendMessage('Update crop limits into gui', self.GetLimits())
+        Publisher.sendMessage('Update crop limits into gui', limits=self.GetLimits())
 
 
     def GetLimits(self):
@@ -356,7 +356,7 @@ class DrawCrop2DRetangle():
             x_pos_sl = x_pos_sl_ * xs
             y_pos_sl = y_pos_sl_ * ys
 
-            for k, p in self.box.axial.iteritems():
+            for k, p in self.box.axial.items():
                 p0 = p[0]
                 p1 = p[1]
 
@@ -386,7 +386,7 @@ class DrawCrop2DRetangle():
             x_pos_sl = x_pos_sl_ * xs
             y_pos_sl = y_pos_sl_ * zs
             
-            for k, p in self.box.coronal.iteritems():
+            for k, p in self.box.coronal.items():
                 p0 = p[0]
                 p1 = p[1]
 
@@ -415,7 +415,7 @@ class DrawCrop2DRetangle():
             x_pos_sl = x_pos_sl_ * ys
             y_pos_sl = y_pos_sl_ * zs
 
-            for k, p in self.box.sagital.iteritems():
+            for k, p in self.box.sagital.items():
                 p0 = p[0]
                 p1 = p[1]
 
