@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
+from six import with_metaclass
+
 import math
 import random
 import sys
@@ -46,11 +48,10 @@ else:
     MEASURE_TEXT_COLOUR = (0, 0, 0)
     MEASURE_TEXTBOX_COLOUR = (255, 255, 165, 255)
 
-class MeasureData:
+class MeasureData(with_metaclass(utils.Singleton)):
     """
     Responsible to keep measures data.
     """
-    __metaclass__= utils.Singleton
     def __init__(self):
         self.measures = {const.SURFACE: {},
                          const.AXIAL:   {},
@@ -119,14 +120,9 @@ class MeasurementManager(object):
         Publisher.subscribe(self._change_measure_point_pos, 'Change measurement point position')
         Publisher.subscribe(self.OnCloseProject, 'Close project data')
 
-    def _load_measurements(self, pubsub_evt):
-        try:
-            dict, spacing = pubsub_evt.data
-        except ValueError:
-            dict = pubsub_evt.data
-            spacing = 1.0, 1.0, 1.0
-        for i in dict:
-            m = dict[i]
+    def _load_measurements(self, measurement_dict, spacing=(1.0, 1.0, 1.0)):
+        for i in measurement_dict:
+            m = measurement_dict[i]
 
             if m.location == const.AXIAL:
                 radius = min(spacing[1], spacing[2]) * const.PROP_MEASURE
@@ -153,7 +149,7 @@ class MeasurementManager(object):
 
                 if m.location == const.SURFACE:
                     Publisher.sendMessage(("Add actors " + str(m.location)),
-                        (actors, m.slice_number))
+                        actors=actors)
             self.current = None
 
             if not m.visible:
@@ -163,28 +159,7 @@ class MeasurementManager(object):
                 else:
                     Publisher.sendMessage('Redraw canvas')
 
-    def _add_point(self, pubsub_evt):
-        position = pubsub_evt.data[0]
-        type = pubsub_evt.data[1] # Linear or Angular
-        location = pubsub_evt.data[2] # 3D, AXIAL, SAGITAL, CORONAL
-
-        if location == const.SURFACE:
-            slice_number = 0
-            try:
-                radius = pubsub_evt.data[3]
-            except IndexError:
-                radius = const.PROP_MEASURE
-        else:
-            try:
-                slice_number = pubsub_evt.data[3]
-            except IndexError:
-                slice_number = 0
-
-            try:
-                radius = pubsub_evt.data[4]
-            except IndexError:
-                radius = const.PROP_MEASURE
-
+    def _add_point(self, position, type, location, slice_number=0, radius=const.PROP_MEASURE):
         to_remove = False
         if self.current is None:
             to_create = True
@@ -232,8 +207,7 @@ class MeasurementManager(object):
         m.points.append(position)
 
         if m.location == const.SURFACE:
-            Publisher.sendMessage("Add actors " + str(location),
-                    (actors, m.slice_number))
+            Publisher.sendMessage("Add actors " + str(location), actors=actors)
 
         if self.current not in self.measures:
             self.measures.append(self.current)
@@ -253,14 +227,12 @@ class MeasurementManager(object):
 
             msg =  'Update measurement info in GUI',
             Publisher.sendMessage(msg,
-                                  (index, name, colour,
-                                   location,
-                                   type_,
-                                   value))
+                                  index=index, name=name,
+                                  colour=colour, location=location,
+                                  type_=type_, value=value)
             self.current = None
 
-    def _change_measure_point_pos(self, pubsub_evt):
-        index, npoint, pos = pubsub_evt.data
+    def _change_measure_point_pos(self, index, npoint, pos):
         m, mr = self.measures[index]
         x, y, z = pos
         if npoint == 0:
@@ -287,17 +259,14 @@ class MeasurementManager(object):
             value = u"%.3f°"% m.value
 
         Publisher.sendMessage('Update measurement info in GUI',
-                              (index, name, colour,
-                               location,
-                               type_,
-                               value))
+                              index=index, name=name, colour=colour,
+                              location=location, type_=type_,
+                              value=value)
 
-    def _change_name(self, pubsub_evt):
-        index, new_name = pubsub_evt.data
-        self.measures[index].name = new_name
+    def _change_name(self, index, name):
+        self.measures[index][0].name = name
 
-    def _remove_measurements(self, pubsub_evt):
-        indexes = pubsub_evt.data
+    def _remove_measurements(self, indexes):
         for index in indexes:
             m, mr = self.measures.pop(index)
             try:
@@ -307,16 +276,15 @@ class MeasurementManager(object):
                 pass
             prj.Project().RemoveMeasurement(index)
             if m.location == const.SURFACE:
-                Publisher.sendMessage(('Remove actors ' + str(m.location)),
-                        (mr.GetActors(), m.slice_number))
+                Publisher.sendMessage('Remove actors ' + str(m.location),
+                                      actors=mr.GetActors())
         Publisher.sendMessage('Redraw canvas')
         Publisher.sendMessage('Render volume viewer')
 
         session = ses.Session()
         session.ChangeProject()
 
-    def _set_visibility(self, pubsub_evt):
-        index, visibility = pubsub_evt.data
+    def _set_visibility(self, index, visibility):
         m, mr = self.measures[index]
         m.visible = visibility
         mr.SetVisibility(visibility)
@@ -325,7 +293,7 @@ class MeasurementManager(object):
         else:
             Publisher.sendMessage('Redraw canvas')
 
-    def _rm_incomplete_measurements(self, pubsub_evt):
+    def _rm_incomplete_measurements(self):
         if self.current is None:
             return
 
@@ -333,12 +301,12 @@ class MeasurementManager(object):
         if not mr.IsComplete():
             idx = self.measures._list_measures.index((m, mr))
             self.measures.remove((m, mr))
-            Publisher.sendMessage("Remove GUI measurement", idx)
+            Publisher.sendMessage("Remove GUI measurement", measure_index=idx)
             actors = mr.GetActors()
             slice_number = self.current[0].slice_number
             if m.location == const.SURFACE:
                 Publisher.sendMessage(('Remove actors ' + str(self.current[0].location)),
-                                      (actors, slice_number))
+                                      actors=actors)
             if self.current[0].location == const.SURFACE:
                 Publisher.sendMessage('Render volume viewer')
             else:
@@ -348,7 +316,7 @@ class MeasurementManager(object):
                 #  self.measures.pop()
             self.current = None
 
-    def OnCloseProject(self, pubsub_evt):
+    def OnCloseProject(self):
         self.measures.clean()
 
 
@@ -358,7 +326,7 @@ class Measurement():
         Measurement.general_index += 1
         self.index = Measurement.general_index
         self.name = const.MEASURE_NAME_PATTERN %(self.index+1)
-        self.colour = const.MEASURE_COLOUR.next()
+        self.colour = next(const.MEASURE_COLOUR)
         self.value = 0
         self.location = const.SURFACE # AXIAL, CORONAL, SAGITTAL
         self.type = const.LINEAR # ANGULAR
@@ -649,7 +617,7 @@ class LinearMeasure(object):
 
     def Remove(self):
         actors = self.GetActors()
-        Publisher.sendMessage("Remove actors " + str(const.SURFACE), (actors,))
+        Publisher.sendMessage("Remove actors " + str(const.SURFACE), actors=actors)
 
     def __del__(self):
         self.Remove()
@@ -832,7 +800,7 @@ class AngularMeasure(object):
         for p in self.points:
             coord.SetValue(p)
             cx, cy = coord.GetComputedDoubleDisplayValue(canvas.evt_renderer)
-            print cx, cy
+            print(cx, cy)
             #  canvas.draw_circle((cx, cy), 2.5)
             points.append((cx, cy))
 
@@ -900,7 +868,7 @@ class AngularMeasure(object):
 
     def Remove(self):
         actors = self.GetActors()
-        Publisher.sendMessage("Remove actors " + str(const.SURFACE), (actors,))
+        Publisher.sendMessage("Remove actors " + str(const.SURFACE), actors=actors)
 
     def SetRenderer(self, renderer):
         if self.point_actor1:
