@@ -17,6 +17,8 @@
 #    detalhes.
 #--------------------------------------------------------------------------
 
+from six import with_metaclass
+
 import os
 import multiprocessing
 import tempfile
@@ -212,12 +214,12 @@ class CrossInteractorStyle(DefaultInteractorStyle):
     def SetUp(self):
         self.viewer._set_cross_visibility(1)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                              _id=self.state_code, value=True)
 
     def CleanUp(self):
         self.viewer._set_cross_visibility(0)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                              _id=self.state_code, value=False)
 
     def OnCrossMouseClick(self, obj, evt):
         iren = obj.GetInteractor()
@@ -226,7 +228,7 @@ class CrossInteractorStyle(DefaultInteractorStyle):
     def OnCrossMove(self, obj, evt):
         # The user moved the mouse with left button pressed
         if self.left_pressed:
-            print "OnCrossMove interactor style"
+            print("OnCrossMove interactor style")
             iren = obj.GetInteractor()
             self.ChangeCrossPosition(iren)
 
@@ -235,29 +237,29 @@ class CrossInteractorStyle(DefaultInteractorStyle):
         wx, wy, wz = self.viewer.get_coordinate_cursor(mouse_x, mouse_y, self.picker)
         px, py = self.viewer.get_slice_pixel_coord_by_world_pos(wx, wy, wz)
         coord = self.viewer.calcultate_scroll_position(px, py)
-        Publisher.sendMessage('Update cross position', (wx, wy, wz))
+        Publisher.sendMessage('Update cross position', position=(wx, wy, wz))
         self.ScrollSlice(coord)
-        Publisher.sendMessage('Set ball reference position', (wx, wy, wz))
-        Publisher.sendMessage('Set camera in volume', (wx, wy, wz))
+        Publisher.sendMessage('Set ball reference position', position=(wx, wy, wz))
+        Publisher.sendMessage('Co-registered points',  arg=None, position=(wx, wy, wz, 0., 0., 0.))
 
         iren.Render()
 
     def ScrollSlice(self, coord):
         if self.orientation == "AXIAL":
             Publisher.sendMessage(('Set scroll position', 'SAGITAL'),
-                                       coord[0])
+                                       index=coord[0])
             Publisher.sendMessage(('Set scroll position', 'CORONAL'),
-                                       coord[1])
+                                       index=coord[1])
         elif self.orientation == "SAGITAL":
             Publisher.sendMessage(('Set scroll position', 'AXIAL'),
-                                       coord[2])
+                                       index=coord[2])
             Publisher.sendMessage(('Set scroll position', 'CORONAL'),
-                                       coord[1])
+                                       index=coord[1])
         elif self.orientation == "CORONAL":
             Publisher.sendMessage(('Set scroll position', 'AXIAL'),
-                                       coord[2])
+                                       index=coord[2])
             Publisher.sendMessage(('Set scroll position', 'SAGITAL'),
-                                       coord[0])
+                                       index=coord[0])
 
 
 class WWWLInteractorStyle(DefaultInteractorStyle):
@@ -283,14 +285,14 @@ class WWWLInteractorStyle(DefaultInteractorStyle):
     def SetUp(self):
         self.viewer.on_wl = True
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                              _id=self.state_code, value=True)
         self.viewer.canvas.draw_list.append(self.viewer.wl_text)
         self.viewer.UpdateCanvas()
 
     def CleanUp(self):
         self.viewer.on_wl = False
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                              _id=self.state_code, value=False)
         if self.viewer.wl_text is not None:
             self.viewer.canvas.draw_list.remove(self.viewer.wl_text)
             self.viewer.UpdateCanvas()
@@ -304,7 +306,8 @@ class WWWLInteractorStyle(DefaultInteractorStyle):
             self.last_x, self.last_y = mouse_x, mouse_y
 
             Publisher.sendMessage('Bright and contrast adjustment image',
-                (self.acum_achange_window, self.acum_achange_level))
+                                  window=self.acum_achange_window,
+                                  level=self.acum_achange_level)
 
             #self.SetWLText(self.acum_achange_level,
             #              self.acum_achange_window)
@@ -312,8 +315,9 @@ class WWWLInteractorStyle(DefaultInteractorStyle):
             const.WINDOW_LEVEL['Manual'] = (self.acum_achange_window,\
                                            self.acum_achange_level)
             Publisher.sendMessage('Check window and level other')
-            Publisher.sendMessage('Update window level value',(self.acum_achange_window,
-                                                                self.acum_achange_level))
+            Publisher.sendMessage('Update window level value',
+                                  window=self.acum_achange_window,
+                                  level= self.acum_achange_level)
             #Necessary update the slice plane in the volume case exists
             Publisher.sendMessage('Update slice viewer')
             Publisher.sendMessage('Render volume viewer')
@@ -372,11 +376,11 @@ class LinearMeasureInteractorStyle(DefaultInteractorStyle):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                             _id=self.state_code, value=True)
 
     def CleanUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                             _id=self.state_code, value=False)
         self.picker.PickFromListOff()
         Publisher.sendMessage("Remove incomplete measurements")
 
@@ -397,9 +401,9 @@ class LinearMeasureInteractorStyle(DefaultInteractorStyle):
                 self.viewer.scroll_enabled = True
             else:
                 Publisher.sendMessage("Add measurement point",
-                                      ((x, y, z), self._type,
-                                       ORIENTATIONS[self.orientation],
-                                       slice_number, self.radius))
+                                      position=(x, y, z), type=self._type,
+                                      location=ORIENTATIONS[self.orientation],
+                                      slice_number=slice_number, radius=self.radius)
                 n = len(m.points)-1
                 self.creating = n, m, mr
                 self.viewer.UpdateCanvas()
@@ -414,13 +418,15 @@ class LinearMeasureInteractorStyle(DefaultInteractorStyle):
             if self.picker.GetViewProp():
                 renderer = self.viewer.slice_data.renderer
                 Publisher.sendMessage("Add measurement point",
-                                      ((x, y, z), self._type,
-                                       ORIENTATIONS[self.orientation],
-                                       slice_number, self.radius))
+                                      position=(x, y, z), type=self._type,
+                                      location=ORIENTATIONS[self.orientation],
+                                      slice_number=slice_number,
+                                      radius=self.radius)
                 Publisher.sendMessage("Add measurement point",
-                                      ((x, y, z), self._type,
-                                       ORIENTATIONS[self.orientation],
-                                       slice_number, self.radius))
+                                      position=(x, y, z), type=self._type,
+                                      location=ORIENTATIONS[self.orientation],
+                                      slice_number=slice_number,
+                                      radius=self.radius)
 
                 n, (m, mr) =  1, self.measures.measures[self._ori][slice_number][-1]
                 self.creating = n, m, mr
@@ -432,7 +438,7 @@ class LinearMeasureInteractorStyle(DefaultInteractorStyle):
             n, m, mr = self.selected
             x, y, z = self._get_pos_clicked()
             idx = self.measures._list_measures.index((m, mr))
-            Publisher.sendMessage('Change measurement point position', (idx, n, (x, y, z)))
+            Publisher.sendMessage('Change measurement point position', index=idx, npoint=n, pos=(x, y, z))
             self.viewer.UpdateCanvas()
             self.selected = None
             self.viewer.scroll_enabled = True
@@ -442,13 +448,13 @@ class LinearMeasureInteractorStyle(DefaultInteractorStyle):
         if self.selected:
             n, m, mr = self.selected
             idx = self.measures._list_measures.index((m, mr))
-            Publisher.sendMessage('Change measurement point position', (idx, n, (x, y, z)))
+            Publisher.sendMessage('Change measurement point position', index=idx, npoint=n, pos=(x, y, z))
             self.viewer.UpdateCanvas()
 
         elif self.creating:
             n, m, mr = self.creating
             idx = self.measures._list_measures.index((m, mr))
-            Publisher.sendMessage('Change measurement point position', (idx, n, (x, y, z)))
+            Publisher.sendMessage('Change measurement point position', index=idx, npoint=n, pos=(x, y, z))
             self.viewer.UpdateCanvas()
 
         else:
@@ -537,11 +543,12 @@ class PanMoveInteractorStyle(DefaultInteractorStyle):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                             _id=self.state_code, value=True)
 
     def CleanUp(self):
+        self.viewer.interactor.Unbind(wx.EVT_LEFT_DCLICK)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                             _id=self.state_code, value=False)
 
     def OnPanMove(self, obj, evt):
         if self.left_pressed:
@@ -572,11 +579,12 @@ class SpinInteractorStyle(DefaultInteractorStyle):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                              _id=self.state_code, value=True)
 
     def CleanUp(self):
+        self.viewer.interactor.Unbind(wx.EVT_LEFT_DCLICK)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                              _id=self.state_code, value=False)
 
     def OnSpinMove(self, obj, evt):
         iren = obj.GetInteractor()
@@ -616,11 +624,12 @@ class ZoomInteractorStyle(DefaultInteractorStyle):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                             _id=self.state_code, value=True)
 
     def CleanUp(self):
+        self.viewer.interactor.Unbind(wx.EVT_LEFT_DCLICK)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                              _id=self.state_code, value=False)
 
     def OnZoomMoveLeft(self, obj, evt):
         if self.left_pressed:
@@ -649,11 +658,12 @@ class ZoomSLInteractorStyle(vtk.vtkInteractorStyleRubberBandZoom):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                              _id=self.state_code, value=True)
 
     def CleanUp(self):
+        self.viewer.interactor.Unbind(wx.EVT_LEFT_DCLICK)
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                              _id=self.state_code, value=False)
 
     def OnUnZoom(self, evt):
         mouse_x, mouse_y = self.viewer.interactor.GetLastEventPosition()
@@ -681,11 +691,11 @@ class ChangeSliceInteractorStyle(DefaultInteractorStyle):
 
     def SetUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, True))
+                             _id=self.state_code, value=True)
 
     def CleanUp(self):
         Publisher.sendMessage('Toggle toolbar item',
-                             (self.state_code, False))
+                             _id=self.state_code, value=False)
 
     def OnChangeSliceMove(self, evt, obj):
         if self.left_pressed:
@@ -712,8 +722,7 @@ class ChangeSliceInteractorStyle(DefaultInteractorStyle):
         self.last_position = position[1]
 
 
-class EditorConfig(object):
-    __metaclass__= utils.Singleton
+class EditorConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.operation = const.BRUSH_THRESH
         self.cursor_type = const.BRUSH_CIRCLE
@@ -752,22 +761,38 @@ class EditorInteractorStyle(DefaultInteractorStyle):
         self._set_cursor()
         self.viewer.slice_data.cursor.Show(0)
 
+    def SetUp(self):
+         
+        x, y = self.viewer.interactor.ScreenToClient(wx.GetMousePosition())
+        if self.viewer.interactor.HitTest((x, y)) == wx.HT_WINDOW_INSIDE:
+            self.viewer.slice_data.cursor.Show()
+            
+            y = self.viewer.interactor.GetSize()[1] - y
+            w_x, w_y, w_z = self.viewer.get_coordinate_cursor(x, y, self.picker)
+            self.viewer.slice_data.cursor.SetPosition((w_x, w_y, w_z))
+            
+            self.viewer.interactor.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
+            self.viewer.interactor.Render()
+
     def CleanUp(self):
         Publisher.unsubscribe(self.set_bsize, 'Set edition brush size')
         Publisher.unsubscribe(self.set_bformat, 'Set brush format')
         Publisher.unsubscribe(self.set_boperation, 'Set edition operation')
 
-    def set_bsize(self, pubsub_evt):
-        size = pubsub_evt.data
+        self.viewer.slice_data.cursor.Show(0)
+        self.viewer.interactor.SetCursor(wx.StockCursor(wx.CURSOR_DEFAULT))
+        self.viewer.interactor.Render()
+
+    def set_bsize(self, size):
         self.config.cursor_size = size
         self.viewer.slice_data.cursor.SetSize(size)
 
-    def set_bformat(self, pubsub_evt):
-        self.config.cursor_type = pubsub_evt.data
+    def set_bformat(self, cursor_format):
+        self.config.cursor_type = cursor_format
         self._set_cursor()
 
-    def set_boperation(self, pubsub_evt):
-        self.config.operation = pubsub_evt.data
+    def set_boperation(self, operation):
+        self.config.operation = operation
 
     def _set_cursor(self):
         if self.config.cursor_type == const.BRUSH_SQUARE:
@@ -914,7 +939,7 @@ class EditorInteractorStyle(DefaultInteractorStyle):
             size += 1
 
             if size <= 100:
-                Publisher.sendMessage('Set edition brush size', size)
+                Publisher.sendMessage('Set edition brush size', size=size)
                 cursor.SetPosition(cursor.position)
                 self.viewer.interactor.Render()
         else:
@@ -932,7 +957,7 @@ class EditorInteractorStyle(DefaultInteractorStyle):
             size -= 1
 
             if size > 0:
-                Publisher.sendMessage('Set edition brush size', size)
+                Publisher.sendMessage('Set edition brush size', size=size)
                 cursor.SetPosition(cursor.position)
                 self.viewer.interactor.Render()
         else:
@@ -964,8 +989,7 @@ class WatershedProgressWindow(object):
         self.dlg.Destroy()
 
 
-class WatershedConfig(object):
-    __metaclass__= utils.Singleton
+class WatershedConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.algorithm = "Watershed"
         self.con_2d = 4
@@ -984,23 +1008,23 @@ class WatershedConfig(object):
         Publisher.subscribe(self.set_3dcon, "Set watershed 3d con")
         Publisher.subscribe(self.set_gaussian_size, "Set watershed gaussian size")
 
-    def set_operation(self, pubsub_evt):
-        self.operation = WATERSHED_OPERATIONS[pubsub_evt.data]
+    def set_operation(self, operation):
+        self.operation = WATERSHED_OPERATIONS[operation]
 
-    def set_use_ww_wl(self, pubsub_evt):
-        self.use_ww_wl = pubsub_evt.data
+    def set_use_ww_wl(self, use_ww_wl):
+        self.use_ww_wl = use_ww_wl
 
-    def set_algorithm(self, pubsub_evt):
-        self.algorithm = pubsub_evt.data
+    def set_algorithm(self, algorithm):
+        self.algorithm = algorithm
 
-    def set_2dcon(self, pubsub_evt):
-        self.con_2d = pubsub_evt.data
+    def set_2dcon(self, con_2d):
+        self.con_2d = con_2d
 
-    def set_3dcon(self, pubsub_evt):
-        self.con_3d = pubsub_evt.data
+    def set_3dcon(self, con_3d):
+        self.con_3d = con_3d
 
-    def set_gaussian_size(self, pubsub_evt):
-        self.mg_size = pubsub_evt.data
+    def set_gaussian_size(self, size):
+        self.mg_size = size
 
 WALGORITHM = {"Watershed": watershed,
              "Watershed IFT": watershed_ift}
@@ -1041,11 +1065,23 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
         self.viewer.slice_data.cursor.Show(0)
 
     def SetUp(self):
+
         mask = self.viewer.slice_.current_mask.matrix
         self._create_mask()
         self.viewer.slice_.to_show_aux = 'watershed'
         self.viewer.OnScrollBar()
 
+        x, y = self.viewer.interactor.ScreenToClient(wx.GetMousePosition())
+        if self.viewer.interactor.HitTest((x, y)) == wx.HT_WINDOW_INSIDE:
+            self.viewer.slice_data.cursor.Show()
+            
+            y = self.viewer.interactor.GetSize()[1] - y
+            w_x, w_y, w_z = self.viewer.get_coordinate_cursor(x, y, self.picker)
+            self.viewer.slice_data.cursor.SetPosition((w_x, w_y, w_z))
+            
+            self.viewer.interactor.SetCursor(wx.StockCursor(wx.CURSOR_BLANK))
+            self.viewer.interactor.Render()
+
     def CleanUp(self):
         #self._remove_mask()
         Publisher.unsubscribe(self.expand_watershed, 'Expand watershed to 3D ' + self.orientation)
@@ -1055,6 +1091,10 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
         self.viewer.slice_.to_show_aux = ''
         self.viewer.OnScrollBar()
 
+        self.viewer.slice_data.cursor.Show(0)
+        self.viewer.interactor.SetCursor(wx.StockCursor(wx.CURSOR_DEFAULT))
+        self.viewer.interactor.Render()
+
     def _create_mask(self):
         if self.matrix is None:
             try:
@@ -1067,7 +1107,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
         if self.matrix is not None:
             self.matrix = None
             os.remove(self.temp_file)
-            print "deleting", self.temp_file
+            print("deleting", self.temp_file)
 
     def _set_cursor(self):
         if self.config.cursor_type == const.BRUSH_SQUARE:
@@ -1087,13 +1127,12 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
         cursor.SetSize(self.config.cursor_size)
         self.viewer.slice_data.SetCursor(cursor)
 
-    def set_bsize(self, pubsub_evt):
-        size = pubsub_evt.data
+    def set_bsize(self, size):
         self.config.cursor_size = size
         self.viewer.slice_data.cursor.SetSize(size)
 
-    def set_bformat(self, pubsub_evt):
-        self.config.cursor_type = pubsub_evt.data
+    def set_bformat(self, brush_format):
+        self.config.cursor_type = brush_format
         self._set_cursor()
 
     def OnEnterInteractor(self, obj, evt):
@@ -1120,7 +1159,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
             size -= 1
 
             if size > 0:
-                Publisher.sendMessage('Set watershed brush size', size)
+                Publisher.sendMessage('Set watershed brush size', size=size)
                 cursor.SetPosition(cursor.position)
                 self.viewer.interactor.Render()
         else:
@@ -1138,7 +1177,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
             size += 1
 
             if size <= 100:
-                Publisher.sendMessage('Set watershed brush size', size)
+                Publisher.sendMessage('Set watershed brush size', size=size)
                 cursor.SetPosition(cursor.position)
                 self.viewer.interactor.Render()
         else:
@@ -1212,7 +1251,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
             position = self.viewer.get_slice_pixel_coord_by_world_pos(*coord)
             radius = cursor.radius
 
-            if position < 0:
+            if isinstance(position, int) and position < 0:
                 position = viewer.calculate_matrix_position(coord)
 
             operation = self.config.operation
@@ -1386,7 +1425,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
         if roi_m.size:
             roi_m[index] = operation
 
-    def expand_watershed(self, pubsub_evt):
+    def expand_watershed(self):
         markers = self.matrix
         image = self.viewer.slice_.matrix
         self.viewer.slice_.do_threshold_to_all_slices()
@@ -1418,7 +1457,7 @@ class WaterShedInteractorStyle(DefaultInteractorStyle):
             del wp
 
             w_x, w_y = wx.GetMousePosition()
-            x, y = self.viewer.ScreenToClientXY(w_x, w_y)
+            x, y = self.viewer.ScreenToClient((w_x, w_y))
             flag = self.viewer.interactor.HitTest((x, y))
 
             if flag == wx.HT_WINDOW_INSIDE:
@@ -1511,6 +1550,8 @@ class ReorientImageInteractorStyle(DefaultInteractorStyle):
         Publisher.sendMessage('Reload actual slice')
 
     def CleanUp(self):
+        self.viewer.interactor.Unbind(wx.EVT_LEFT_DCLICK)
+
         for actor in self.actors:
             self.viewer.slice_data.renderer.RemoveActor(actor)
 
@@ -1592,7 +1633,7 @@ class ReorientImageInteractorStyle(DefaultInteractorStyle):
         self.viewer.slice_.rotations = [0, 0, 0]
         self.viewer.slice_.q_orientation = np.array((1, 0, 0, 0))
 
-        Publisher.sendMessage('Update reorient angles', (0, 0, 0))
+        Publisher.sendMessage('Update reorient angles', angles=(0, 0, 0))
 
         self._discard_buffers()
         self.viewer.slice_.current_mask.clear_history()
@@ -1648,10 +1689,11 @@ class ReorientImageInteractorStyle(DefaultInteractorStyle):
         self.viewer.slice_.q_orientation = transformations.quaternion_multiply(self.viewer.slice_.q_orientation, transformations.quaternion_about_axis(angle, axis))
 
         az, ay, ax = transformations.euler_from_quaternion(self.viewer.slice_.q_orientation)
-        Publisher.sendMessage('Update reorient angles', (ax, ay, az))
+        Publisher.sendMessage('Update reorient angles', angles=(ax, ay, az))
 
         self._discard_buffers()
-        self.viewer.slice_.current_mask.clear_history()
+        if self.viewer.slice_.current_mask:
+            self.viewer.slice_.current_mask.clear_history()
         Publisher.sendMessage('Reload actual slice %s' % self.viewer.orientation)
         self.p0 = self.get_image_point_coord(x, y, z)
 
@@ -1673,8 +1715,8 @@ class ReorientImageInteractorStyle(DefaultInteractorStyle):
         #  print (z, y, x), tcoord
         return tcoord
 
-    def _set_reorientation_angles(self, pubsub_evt):
-        ax, ay, az = pubsub_evt.data
+    def _set_reorientation_angles(self, angles):
+        ax, ay, az = angles
         q = transformations.quaternion_from_euler(az, ay, ax)
         self.viewer.slice_.q_orientation = q
 
@@ -1727,8 +1769,7 @@ class ReorientImageInteractorStyle(DefaultInteractorStyle):
             buffer_.discard_image()
 
 
-class FFillConfig(object):
-    __metaclass__= utils.Singleton
+class FFillConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.dlg_visible = False
         self.target = "2D"
@@ -1864,8 +1905,7 @@ class RemoveMaskPartsInteractorStyle(FloodFillMaskInteractorStyle):
         self._progr_title = _(u"Remove part")
         self._progr_msg = _(u"Removing part ...")
 
-class CropMaskConfig(object):
-    __metaclass__= utils.Singleton
+class CropMaskConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.dlg_visible = False
 
@@ -1930,9 +1970,8 @@ class CropMaskInteractorStyle(DefaultInteractorStyle):
         self.viewer.canvas.draw_list.remove(self.draw_retangle)
         Publisher.sendMessage('Redraw canvas')
 
-    def CropMask(self, pubsub_evt):
+    def CropMask(self):
         if self.viewer.orientation == "AXIAL":
-            
             xi, xf, yi, yf, zi, zf = self.draw_retangle.box.GetLimits()
 
             xi += 1
@@ -1940,7 +1979,7 @@ class CropMaskInteractorStyle(DefaultInteractorStyle):
 
             yi += 1
             yf += 1
-            
+
             zi += 1
             zf += 1
 
@@ -1948,13 +1987,13 @@ class CropMaskInteractorStyle(DefaultInteractorStyle):
             cp_mask = self.viewer.slice_.current_mask.matrix.copy()
 
             tmp_mask = self.viewer.slice_.current_mask.matrix[zi-1:zf+1, yi-1:yf+1, xi-1:xf+1].copy()
-            
+
             self.viewer.slice_.current_mask.matrix[:] = 1
 
             self.viewer.slice_.current_mask.matrix[zi-1:zf+1, yi-1:yf+1, xi-1:xf+1] = tmp_mask
 
             self.viewer.slice_.current_mask.save_history(0, 'VOLUME', self.viewer.slice_.current_mask.matrix.copy(), cp_mask)
-            
+
             self.viewer.slice_.buffer_slices['AXIAL'].discard_mask()
             self.viewer.slice_.buffer_slices['CORONAL'].discard_mask()
             self.viewer.slice_.buffer_slices['SAGITAL'].discard_mask()
@@ -1964,11 +2003,10 @@ class CropMaskInteractorStyle(DefaultInteractorStyle):
             self.viewer.slice_.buffer_slices['SAGITAL'].discard_vtk_mask()
 
             self.viewer.slice_.current_mask.was_edited = True
-            Publisher.sendMessage('Reload actual slice')           
+            Publisher.sendMessage('Reload actual slice')
 
-     
-class SelectPartConfig(object):
-    __metaclass__= utils.Singleton
+
+class SelectPartConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.mask = None
         self.con_3d = 6
@@ -2029,7 +2067,7 @@ class SelectMaskPartsInteractorStyle(DefaultInteractorStyle):
                 self.config.mask.name = self.config.mask_name
                 self.viewer.slice_._add_mask_into_proj(self.config.mask)
                 self.viewer.slice_.SelectCurrentMask(self.config.mask.index)
-                Publisher.sendMessage('Change mask selected', self.config.mask.index)
+                Publisher.sendMessage('Change mask selected', index=self.config.mask.index)
 
             del self.viewer.slice_.aux_matrices['SELECT']
             self.viewer.slice_.to_show_aux = ''
@@ -2074,8 +2112,7 @@ class SelectMaskPartsInteractorStyle(DefaultInteractorStyle):
         self.config.mask = mask
 
 
-class FFillSegmentationConfig(object):
-    __metaclass__= utils.Singleton
+class FFillSegmentationConfig(with_metaclass(utils.Singleton, object)):
     def __init__(self):
         self.dlg_visible = False
         self.target = "2D"
@@ -2185,7 +2222,7 @@ class FloodFillSegmentInteractorStyle(DefaultInteractorStyle):
 
             elif self.config.method == 'dynamic':
                 if self.config.use_ww_wl:
-                    print "Using WW&WL"
+                    print("Using WW&WL")
                     ww = self.viewer.slice_.window_width
                     wl = self.viewer.slice_.window_level
                     image = get_LUT_value_255(image, ww, wl)
@@ -2242,7 +2279,7 @@ class FloodFillSegmentInteractorStyle(DefaultInteractorStyle):
 
             elif self.config.method == 'dynamic':
                 if self.config.use_ww_wl:
-                    print "Using WW&WL"
+                    print("Using WW&WL")
                     ww = self.viewer.slice_.window_width
                     wl = self.viewer.slice_.window_level
                     image = get_LUT_value_255(image, ww, wl)
@@ -2295,18 +2332,18 @@ class FloodFillSegmentInteractorStyle(DefaultInteractorStyle):
         bool_mask = np.zeros_like(mask, dtype='bool')
         out_mask = np.zeros_like(mask)
 
-        for k in xrange(int(z-1), int(z+2)):
+        for k in range(int(z-1), int(z+2)):
             if k < 0 or k >= bool_mask.shape[0]:
                 continue
-            for j in xrange(int(y-1), int(y+2)):
+            for j in range(int(y-1), int(y+2)):
                 if j < 0 or j >= bool_mask.shape[1]:
                     continue
-                for i in xrange(int(x-1), int(x+2)):
+                for i in range(int(x-1), int(x+2)):
                     if i < 0 or i >= bool_mask.shape[2]:
                         continue
                     bool_mask[k, j, i] = True
 
-        for i in xrange(self.config.confid_iters):
+        for i in range(self.config.confid_iters):
             var = np.std(image[bool_mask])
             mean = np.mean(image[bool_mask])
 
