@@ -44,11 +44,16 @@ def ShowProgress(number_of_filters = 1,
     progress = [0]
     last_obj_progress = [0]
     if (dialog_type == "ProgressDialog"):
-        dlg = ProgressDialog(100)
+        try:
+            dlg = ProgressDialog(100)
+        except wx._core.PyNoAppError:
+            return lambda obj, label: 0
 
 
     # when the pipeline is larger than 1, we have to consider this object
     # percentage
+    if number_of_filters < 1:
+        number_of_filters = 1
     ratio = (100.0 / number_of_filters)
 
     def UpdateProgress(obj, label=""):
@@ -76,8 +81,7 @@ def ShowProgress(number_of_filters = 1,
         progress[0] = progress[0] + ratio*difference
         # Tell GUI to update progress status value
         if (dialog_type == "GaugeProgress"):
-            Publisher.sendMessage('Update status in GUI',
-                                        (progress[0], label))
+            Publisher.sendMessage('Update status in GUI', value=progress[0], label=label)
         else:
             if (progress[0] >= 99.999):
                 progress[0] = 100
@@ -121,6 +125,9 @@ class Text(object):
     def ShadowOff(self):
         self.property.ShadowOff()
 
+    def BoldOn(self):
+        self.property.BoldOn()
+
     def SetSize(self, size):
         self.property.SetFontSize(size)
 
@@ -132,11 +139,27 @@ class Text(object):
         # With some encoding in some dicom fields (like name) raises a
         # UnicodeEncodeError because they have non-ascii characters. To avoid
         # that we encode in utf-8.
-        
-	if sys.platform == 'win32':
-            self.mapper.SetInput(value.encode("utf-8"))  
+        if sys.platform == 'win32':
+            self.mapper.SetInput(value.encode("utf-8"))
         else:
-	    try:
+            try:
+                self.mapper.SetInput(value.encode("latin-1"))
+            except(UnicodeEncodeError):
+                self.mapper.SetInput(value.encode("utf-8"))
+
+    def SetCoilDistanceValue(self, value):
+        if isinstance(value, int) or isinstance(value, float):
+            value = 'Dist: ' + str("{:06.2f}".format(value)) + ' mm'
+            if sys.platform == 'win32':
+                value += ""  # Otherwise 0 is not shown under win32
+                # With some encoding in some dicom fields (like name) raises a
+                # UnicodeEncodeError because they have non-ascii characters. To avoid
+                # that we encode in utf-8.
+
+        if sys.platform == 'win32':
+            self.mapper.SetInput(value.encode("utf-8"))
+        else:
+            try:
                 self.mapper.SetInput(value.encode("latin-1"))
             except(UnicodeEncodeError):
                 self.mapper.SetInput(value.encode("utf-8"))
