@@ -218,7 +218,10 @@ class Preview(wx.Panel):
 
     def OnEnter(self, evt):
         if not self.select_on:
-            c = wx.SystemSettings_GetColour(wx.SYS_COLOUR_BTNFACE)
+            try:
+                c = wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNFACE)
+            except AttributeError:
+                c = wx.SystemSettings_GetColour(wx.SYS_COLOUR_BTNFACE)
             self.SetBackgroundColour(c)
 
     def OnLeave(self, evt):
@@ -229,7 +232,7 @@ class Preview(wx.Panel):
     def OnSelect(self, evt):
 
         shift_pressed = False
-        if evt.m_shiftDown:
+        if evt.shiftDown:
             shift_pressed = True
 
         self.select_on = True
@@ -246,7 +249,7 @@ class Preview(wx.Panel):
         my_evt.SetEventObject(self)
         self.GetEventHandler().ProcessEvent(my_evt)
 
-        Publisher.sendMessage('Set bitmap in preview panel', self.bitmap_info.pos)
+        Publisher.sendMessage('Set bitmap in preview panel', pos=self.bitmap_info.pos)
 
         evt.Skip()
 
@@ -257,7 +260,10 @@ class Preview(wx.Panel):
 
     def Select(self, on=True):
         if self.select_on:
-            c = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+            try:
+                c = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+            except AttributeError:
+                c = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHT)
         else:
             c = (PREVIEW_BACKGROUND)
         self.SetBackgroundColour(c)
@@ -291,10 +297,10 @@ class BitmapPreviewSeries(wx.Panel):
         self.grid = wx.GridSizer(rows=NROWS, cols=NCOLS, vgap=3, hgap=3)
 
         sizer = wx.BoxSizer(wx.HORIZONTAL)
-        sizer.AddSizer(self.grid, 1, wx.EXPAND|wx.GROW|wx.ALL, 2)
+        sizer.Add(self.grid, 1, wx.EXPAND|wx.GROW|wx.ALL, 2)
 
         background_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        background_sizer.AddSizer(sizer, 1, wx.EXPAND|wx.GROW|wx.ALL, 2)
+        background_sizer.Add(sizer, 1, wx.EXPAND|wx.GROW|wx.ALL, 2)
         background_sizer.Add(scroll, 0, wx.EXPAND|wx.GROW)
         self.SetSizer(background_sizer)
         background_sizer.Fit(self)
@@ -311,8 +317,8 @@ class BitmapPreviewSeries(wx.Panel):
 
     def _Add_Panels_Preview(self):
         self.previews = []
-        for i in xrange(NROWS):
-            for j in xrange(NCOLS):
+        for i in range(NROWS):
+            for j in range(NCOLS):
                 p = Preview(self)
                 p.Bind(EVT_PREVIEW_CLICK, self.OnSelect)
 
@@ -363,15 +369,14 @@ class BitmapPreviewSeries(wx.Panel):
         self._display_previews()
 
 
-    def RemovePanel(self, pub_sub):
-        data = pub_sub.data
+    def RemovePanel(self, data):
         for p, f in zip(self.previews, self.files):
             if p.bitmap_info != None:
                 if data.encode('utf-8') in p.bitmap_info.data:
                     self.files.remove(f)
                     p.Hide()
                     self._display_previews()
-                    Publisher.sendMessage('Update max of slidebar in single preview image', len(self.files))
+                    Publisher.sendMessage('Update max of slidebar in single preview image', max_value=len(self.files))
 
                     self.Update()
                     self.Layout()
@@ -387,7 +392,7 @@ class BitmapPreviewSeries(wx.Panel):
         initial = self.displayed_position * NCOLS
         final = initial + NUM_PREVIEWS
         if len(self.files) < final:
-            for i in xrange(final-len(self.files)):
+            for i in range(final-len(self.files)):
                 try:
                     self.previews[-i-1].Hide()
                 except IndexError:
@@ -396,7 +401,7 @@ class BitmapPreviewSeries(wx.Panel):
             self.nhidden_last_display = final-len(self.files)
         else:
             if self.nhidden_last_display:
-                for i in xrange(self.nhidden_last_display):
+                for i in range(self.nhidden_last_display):
                     try:
                         self.previews[-i-1].Show()
                     except IndexError:
@@ -504,7 +509,7 @@ class SingleImagePreview(wx.Panel):
                             maxValue=99,
                             style=wx.SL_HORIZONTAL|wx.SL_AUTOTICKS)
         slider.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
-        slider.SetTickFreq(1, 1)
+        slider.SetTickFreq(1)
         self.slider = slider
 
         checkbox = wx.CheckBox(self, -1, _("Auto-play"))
@@ -533,8 +538,7 @@ class SingleImagePreview(wx.Panel):
         Publisher.subscribe(self.UpdateMaxValueSliderBar, 'Update max of slidebar in single preview image')
         Publisher.subscribe(self.ShowBlackSlice, 'Show black slice in single preview image')
 
-    def ShowBitmapByPosition(self, evt):
-        pos = evt.data
+    def ShowBitmapByPosition(self, pos):
         if pos != None:
             self.ShowSlice(int(pos))
 
@@ -578,8 +582,8 @@ class SingleImagePreview(wx.Panel):
         self.slider.SetValue(0)
         self.ShowSlice()
 
-    def UpdateMaxValueSliderBar(self, pub_sub):
-        self.slider.SetMax(pub_sub.data - 1)
+    def UpdateMaxValueSliderBar(self, max_value):
+        self.slider.SetMax(max_value - 1)
         self.slider.Refresh()
         self.slider.Update()
 
