@@ -18,7 +18,10 @@
 #--------------------------------------------------------------------------
 
 import wx
-import wx.lib.foldpanelbar as fpb
+try:
+    import wx.lib.agw.foldpanelbar as fpb
+except ModuleNotFoundError:
+    import wx.lib.foldpanelbar as fpb
 from wx.lib.pubsub import pub as Publisher
 
 import invesalius.constants as const
@@ -35,7 +38,7 @@ FPB_DEFAULT_STYLE = 2621440
 
 def GetCollapsedIconData():
     return \
-'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
+b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
 \x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
 \x00\x01\x8eIDAT8\x8d\xa5\x93-n\xe4@\x10\x85?g\x03\n6lh)\xc4\xd2\x12\xc3\x81\
 \xd6\xa2I\x90\x154\xb9\x81\x8f1G\xc8\x11\x16\x86\xcd\xa0\x99F\xb3A\x91\xa1\
@@ -58,13 +61,13 @@ def GetCollapsedIconBitmap():
     return wx.BitmapFromImage(GetCollapsedIconImage())
 
 def GetCollapsedIconImage():
-    import cStringIO
-    stream = cStringIO.StringIO(GetCollapsedIconData())
+    from io import BytesIO
+    stream = BytesIO(GetCollapsedIconData())
     return wx.ImageFromStream(stream)
 
 def GetExpandedIconData():
     return \
-'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
+b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
 \x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
 \x00\x01\x9fIDAT8\x8d\x95\x93\xa1\x8e\xdc0\x14EO\xb2\xc4\xd0\xd2\x12\xb7(mI\
 \xa4%V\xd1lQT4[4-\x9a\xfe\xc1\xc2|\xc6\xc2~BY\x83:A3E\xd3\xa0*\xa4\xd2\x90H!\
@@ -89,8 +92,8 @@ def GetExpandedIconBitmap():
     return wx.BitmapFromImage(GetExpandedIconImage())
 
 def GetExpandedIconImage():
-    import cStringIO
-    stream = cStringIO.StringIO(GetExpandedIconData())
+    from io import BytesIO
+    stream = BytesIO(GetExpandedIconData())
     return wx.ImageFromStream(stream)
 
 
@@ -201,8 +204,7 @@ class LowerTaskPanel(wx.Panel):
     def __bind_events(self):
         Publisher.subscribe(self.OnEnableState, "Enable state project")
 
-    def OnEnableState(self, pubsub_evt):
-        state = pubsub_evt.data
+    def OnEnableState(self, state):
         if state:
             self.SetStateProjectOpen()
         else:
@@ -239,7 +241,7 @@ class UpperTaskPanel(wx.Panel):
         self.overwrite = False
 
         session = ses.Session()
-        print "session mode: ", session.mode
+        print("session mode: ", session.mode)
         if int(session.mode) == const.MODE_RP:
             tasks = [(_("Load data"), importer.TaskPanel),
                      (_("Select region of interest"), slice_.TaskPanel),
@@ -253,7 +255,7 @@ class UpperTaskPanel(wx.Panel):
                      (_("Export data"), exporter.TaskPanel),
                      (_("Navigation system"), navigator.TaskPanel)]
 
-        for i in xrange(len(tasks)):
+        for i in range(len(tasks)):
             (name, panel) = tasks[i]
             # Create panel
             item = fold_panel.AddFoldPanel("%d. %s"%(i+1, name),
@@ -302,25 +304,24 @@ class UpperTaskPanel(wx.Panel):
         Publisher.subscribe(self.OnFoldExport, 'Fold export task')
         Publisher.subscribe(self.SetNavigationMode, "Set navigation mode")
 
-    def OnOverwrite(self, pubsub_evt):
-        self.overwrite = pubsub_evt.data['options']['overwrite']
+    def OnOverwrite(self, surface_parameters):
+        self.overwrite = surface_parameters['options']['overwrite']
 
-    def OnFoldSurface(self, pubsub_evt):
+    def OnFoldSurface(self):
         if not self.overwrite:
             self.fold_panel.Expand(self.fold_panel.GetFoldPanel(2))
 
-    def OnFoldExport(self, pubsub_evt):
+    def OnFoldExport(self):
         self.fold_panel.Expand(self.fold_panel.GetFoldPanel(3))
 
-    def OnEnableState(self, pubsub_evt):
-        state = pubsub_evt.data
+    def OnEnableState(self, state):
         if state:
             self.SetStateProjectOpen()
         else:
             self.SetStateProjectClose()
 
-    def SetNavigationMode(self, pubsub_evt):
-        self.navigation_mode_status = status = pubsub_evt.data
+    def SetNavigationMode(self, status):
+        self.navigation_mode_status = status
         name = _("Navigation system")
         panel = navigator.TaskPanel
         if status and (self.fold_panel.GetCount()<=4):
