@@ -43,6 +43,7 @@ class Panel(wx.Panel):
 
         self.__init_aui_manager()
         self.__bind_events_wx()
+        self.__bind_events()
         #self.__init_four_way_splitter()
         #self.__init_mix()
 
@@ -124,13 +125,16 @@ class Panel(wx.Panel):
         self.aui_manager.Bind(wx.aui.EVT_AUI_PANE_MAXIMIZE, self.OnMaximize)
         self.aui_manager.Bind(wx.aui.EVT_AUI_PANE_RESTORE, self.OnRestore)
 
+    def __bind_events(self):
+        Publisher.subscribe(self._Exit, 'Exit')
+
     def OnMaximize(self, evt):
         if evt.GetPane().name == self.s4.name:
-            Publisher.sendMessage('Show raycasting widget', None)
+            Publisher.sendMessage('Show raycasting widget')
 
     def OnRestore(self, evt):
         if evt.GetPane().name == self.s4.name:
-            Publisher.sendMessage('Hide raycasting widget', None)
+            Publisher.sendMessage('Hide raycasting widget')
 
     def __init_four_way_splitter(self):
 
@@ -152,6 +156,8 @@ class Panel(wx.Panel):
         p4 = volume_viewer.Viewer(self)
         splitter.AppendWindow(p4)
 
+    def _Exit(self):
+        self.aui_manager.UnInit()
 
     def __init_mix(self):
         aui_manager = wx.aui.AuiManager()
@@ -246,31 +252,32 @@ class VolumeInteraction(wx.Panel):
                                 'Refresh raycasting widget points')
         Publisher.subscribe(self.LoadHistogram,
                                 'Load histogram')
+        Publisher.subscribe(self._Exit, 'Exit')
 
     def __update_curve_wwwl_text(self, curve):
         ww, wl = self.clut_raycasting.GetCurveWWWl(curve)
-        Publisher.sendMessage('Set raycasting wwwl', (ww, wl, curve))
+        Publisher.sendMessage('Set raycasting wwwl', ww=ww, wl=wl, curve=curve)
 
-    def ShowRaycastingWidget(self, evt_pubsub=None):
+    def ShowRaycastingWidget(self):
         self.can_show_raycasting_widget = 1
         if self.clut_raycasting.to_draw_points:
             p = self.aui_manager.GetPane(self.clut_raycasting)
             p.Show()
             self.aui_manager.Update()
 
-    def HideRaycastingWidget(self, evt_pubsub=None):
+    def HideRaycastingWidget(self):
         self.can_show_raycasting_widget = 0
         p = self.aui_manager.GetPane(self.clut_raycasting)
         p.Hide()
         self.aui_manager.Update()
 
     def OnPointChanged(self, evt):
-        Publisher.sendMessage('Set raycasting refresh', None)
-        Publisher.sendMessage('Set raycasting curve', evt.GetCurve())
+        Publisher.sendMessage('Set raycasting refresh')
+        Publisher.sendMessage('Set raycasting curve', curve=evt.GetCurve())
         Publisher.sendMessage('Render volume viewer')
 
     def OnCurveSelected(self, evt):
-        Publisher.sendMessage('Set raycasting curve', evt.GetCurve())
+        Publisher.sendMessage('Set raycasting curve', curve=evt.GetCurve())
         Publisher.sendMessage('Render volume viewer')
 
     def OnChangeCurveWL(self, evt):
@@ -278,7 +285,7 @@ class VolumeInteraction(wx.Panel):
         self.__update_curve_wwwl_text(curve)
         Publisher.sendMessage('Render volume viewer')
 
-    def OnSetRaycastPreset(self, evt_pubsub):
+    def OnSetRaycastPreset(self):
         preset = project.Project().raycasting_preset
         p = self.aui_manager.GetPane(self.clut_raycasting)
         self.clut_raycasting.SetRaycastPreset(preset)
@@ -289,16 +296,18 @@ class VolumeInteraction(wx.Panel):
             p.Hide()
         self.aui_manager.Update()
 
-    def LoadHistogram(self, pubsub_evt):
-        histogram = pubsub_evt.data[0]
-        init, end = pubsub_evt.data[1]
+    def LoadHistogram(self, histogram, init, end):
         self.clut_raycasting.SetRange((init, end))
         self.clut_raycasting.SetHistogramArray(histogram, (init, end))
 
-    def RefreshPoints(self, pubsub_evt):
+    def RefreshPoints(self):
         self.clut_raycasting.CalculatePixelPoints()
         self.clut_raycasting.Refresh()
 
+    def _Exit(self):
+        self.aui_manager.UnInit()
+
+
 import wx.lib.platebtn as pbtn
 import wx.lib.buttons as btn
 import wx.lib.pubsub as ps
@@ -306,7 +315,7 @@ import wx.lib.colourselect as csel
 
 import invesalius.constants as const
 
-[BUTTON_RAYCASTING, BUTTON_VIEW, BUTTON_SLICE_PLANE, BUTTON_3D_STEREO] = [wx.NewId() for num in xrange(4)]
+[BUTTON_RAYCASTING, BUTTON_VIEW, BUTTON_SLICE_PLANE, BUTTON_3D_STEREO, BUTTON_TARGET] = [wx.NewId() for num in range(5)]
 RAYCASTING_TOOLS = wx.NewId()
 
 ID_TO_NAME = {}
@@ -346,6 +355,9 @@ class VolumeToolPanel(wx.Panel):
         BMP_3D_STEREO = wx.Bitmap(os.path.join(const.ICON_DIR, "3D_glasses.png"),
                                     wx.BITMAP_TYPE_PNG)
 
+        BMP_TARGET = wx.Bitmap(os.path.join(const.ICON_DIR, "target.png"),
+                                    wx.BITMAP_TYPE_PNG)
+
 
         button_raycasting = pbtn.PlateButton(self, BUTTON_RAYCASTING,"",
                 BMP_RAYCASTING, style=pbtn.PB_STYLE_SQUARE,
@@ -359,6 +371,11 @@ class VolumeToolPanel(wx.Panel):
         BMP_SLICE_PLANE, style=pbtn.PB_STYLE_SQUARE,
         size=(32,32))
 
+        button_target = self.button_target = pbtn.PlateButton(self, BUTTON_TARGET,"",
+        BMP_TARGET, style=pbtn.PB_STYLE_SQUARE|pbtn.PB_STYLE_TOGGLE,
+        size=(32,32))
+        self.button_target.Enable(0)
+
         self.button_raycasting = button_raycasting
         self.button_stereo = button_stereo
 
@@ -371,7 +388,7 @@ class VolumeToolPanel(wx.Panel):
         self.button_view = button_view
 
         # VOLUME COLOUR BUTTON
-        if sys.platform == 'linux2':
+        if sys.platform.startswith('linux'):
             size = (32,32)
             sp = 2
         else:
@@ -389,7 +406,11 @@ class VolumeToolPanel(wx.Panel):
         sizer.Add(button_view, 0, wx.TOP|wx.BOTTOM, 1)
         sizer.Add(button_slice_plane, 0, wx.TOP|wx.BOTTOM, 1)
         sizer.Add(button_stereo, 0, wx.TOP|wx.BOTTOM, 1)
+        sizer.Add(button_target, 0, wx.TOP | wx.BOTTOM, 1)
 
+        self.navigation_status = False
+        self.status_target_select = False
+        self.status_obj_tracker = False
 
         sizer.Fit(self)
 
@@ -408,8 +429,10 @@ class VolumeToolPanel(wx.Panel):
         Publisher.subscribe(self.DisablePreset, 'Close project data')
         Publisher.subscribe(self.Uncheck, 'Uncheck image plane menu')
         Publisher.subscribe(self.DisableVolumeCutMenu, 'Disable volume cut menu')
+        Publisher.subscribe(self.StatusTargetSelect, 'Disable or enable coil tracker')
+        Publisher.subscribe(self.StatusObjTracker, 'Status target button')
         
-    def DisablePreset(self, pubsub_evt):
+    def DisablePreset(self):
         self.off_item.Check(1)
 
 
@@ -419,6 +442,7 @@ class VolumeToolPanel(wx.Panel):
         self.button_view.Bind(wx.EVT_LEFT_DOWN, self.OnButtonView)
         self.button_colour.Bind(csel.EVT_COLOURSELECT, self.OnSelectColour)
         self.button_stereo.Bind(wx.EVT_LEFT_DOWN, self.OnButtonStereo)
+        self.button_target.Bind(wx.EVT_LEFT_DOWN, self.OnButtonTarget)
 
     def OnButtonRaycasting(self, evt):
         # MENU RELATED TO RAYCASTING TYPES
@@ -433,14 +457,36 @@ class VolumeToolPanel(wx.Panel):
     def OnButtonSlicePlane(self, evt):
         self.button_slice_plane.PopupMenu(self.slice_plane_menu)
 
+    def StatusObjTracker(self, status):
+        self.status_obj_tracker = status
+        self.StatusNavigation()
+
+    def StatusTargetSelect(self, status):
+        self.status_target_select = status
+        self.StatusNavigation()
+
+    def StatusNavigation(self):
+        if self.status_target_select and self.status_obj_tracker:
+            self.button_target.Enable(1)
+        else:
+            self.OnButtonTarget(False)
+            self.button_target.Enable(0)
+
+    def OnButtonTarget(self, evt):
+        if not self.button_target.IsPressed() and evt is not False:
+            self.button_target._pressed = True
+            Publisher.sendMessage('Target navigation mode', target_mode=self.button_target._pressed)
+        elif self.button_target.IsPressed() or evt is False:
+            self.button_target._pressed = False
+            Publisher.sendMessage('Target navigation mode', target_mode=self.button_target._pressed)
+
     def OnSavePreset(self, evt):
         d = wx.TextEntryDialog(self, _("Preset name"))
         if d.ShowModal() == wx.ID_OK:
             preset_name = d.GetValue()
-            Publisher.sendMessage(_("Save raycasting preset"),
-                                       preset_name)
+            Publisher.sendMessage("Save raycasting preset", preset_name=preset_name)
 
-    def __init_menus(self, pubsub_evt=None):
+    def __init_menus(self):
         # MENU RELATED TO RAYCASTING TYPES
         menu = self.menu = wx.Menu()
         #print "\n\n"
@@ -527,7 +573,7 @@ class VolumeToolPanel(wx.Panel):
         self.Fit()
         self.Update()
         
-    def DisableVolumeCutMenu(self, pusub_evt):
+    def DisableVolumeCutMenu(self):
         self.menu.Enable(RAYCASTING_TOOLS, 0)
         item = ID_TO_TOOL_ITEM[self.id_cutplane]
         item.Check(0)
@@ -547,23 +593,23 @@ class VolumeToolPanel(wx.Panel):
         label = item.GetLabel()
 
         if not (checked):
-            Publisher.sendMessage('Disable plane', label)
+            Publisher.sendMessage('Disable plane', plane_label=label)
         else:
-            Publisher.sendMessage('Enable plane', label)
+            Publisher.sendMessage('Enable plane', plane_label=label)
 
     def OnMenuStereo(self, evt):
         id = evt.GetId() 
         mode = ID_TO_STEREO_NAME[id]
-        Publisher.sendMessage('Set stereo mode', mode)
+        Publisher.sendMessage('Set stereo mode', mode=mode)
 
 
-    def Uncheck(self, pubsub_evt):        
+    def Uncheck(self):
         for item in self.slice_plane_menu.GetMenuItems():
             if (item.IsChecked()):
                 item.Check(0)
     
-    def ChangeButtonColour(self, pubsub_evt):
-        colour = [i*255 for i in pubsub_evt.data]
+    def ChangeButtonColour(self, colour):
+        colour = [i*255 for i in colour]
         self.button_colour.SetColour(colour)
 
     def OnMenuRaycasting(self, evt):
@@ -573,7 +619,7 @@ class VolumeToolPanel(wx.Panel):
             # Raycassting type was selected
             name = ID_TO_NAME[id]
             Publisher.sendMessage('Load raycasting preset',
-                                          ID_TO_NAME[id])
+                                  preset_name=ID_TO_NAME[id])
             # Enable or disable tools
             if name != const.RAYCASTING_OFF_LABEL:
  	            self.menu_raycasting.Enable(RAYCASTING_TOOLS, 1)
@@ -590,12 +636,12 @@ class VolumeToolPanel(wx.Panel):
             #            i.Check(0)
             if not TOOL_STATE[id]:
                 Publisher.sendMessage('Enable raycasting tool',
-                                          [ID_TO_TOOL[id],1])
+                                      tool_name=ID_TO_TOOL[id], flag=1)
                 TOOL_STATE[id] = True
                 item.Check(1)
             else:
                 Publisher.sendMessage('Enable raycasting tool',
-                                            [ID_TO_TOOL[id],0])
+                                      tool_name=ID_TO_TOOL[id], flag=0)
                 TOOL_STATE[id] = False
                 item.Check(0)
 
@@ -606,10 +652,10 @@ class VolumeToolPanel(wx.Panel):
         self.button_view.SetBitmapSelected(bmp)
 
         Publisher.sendMessage('Set volume view angle',
-                                   evt.GetId())
+                              view=evt.GetId())
         self.Refresh()
 
     def OnSelectColour(self, evt):
         colour = c = [i/255.0 for i in evt.GetValue()]
-        Publisher.sendMessage('Change volume viewer background colour', colour)
+        Publisher.sendMessage('Change volume viewer background colour', colour=colour)
 
