@@ -21,7 +21,12 @@ import os
 import sys
 
 import wx
-import wx.lib.hyperlink as hl
+
+try:
+    import wx.lib.agw.hyperlink as hl
+except ImportError:
+    import wx.lib.hyperlink as hl
+
 import wx.lib.platebtn as pbtn
 from wx.lib.pubsub import pub as Publisher
 
@@ -262,7 +267,7 @@ class InnerTaskPanel(wx.Panel):
         if value:
             filename, filetype = value
             Publisher.sendMessage('Export picture to file',
-                                       (id, filename, filetype))
+                                  orientation=id, filename=filename, filetype=filetype)
 
 
 
@@ -294,7 +299,8 @@ class InnerTaskPanel(wx.Panel):
                     filename = filename + "."+ extension
             filetype = const.FILETYPE_IMAGEDATA
             Publisher.sendMessage('Export mask to file',
-                                            (filename, filetype))
+                                  filename=filename,
+                                  filetype=filetype)
 
 
     def OnLinkExportSurface(self, evt=None):
@@ -330,7 +336,7 @@ class InnerTaskPanel(wx.Panel):
                     if filename.split(".")[-1] != extension:
                         filename = filename + "."+ extension
                 Publisher.sendMessage('Export surface to file',
-                                            (filename, filetype))
+                                      filename=filename, filetype=filetype)
                 if not os.path.exists(filename):
                     dlg = wx.MessageDialog(None,
                                        _("It was not possible to save the surface."),
