@@ -20,9 +20,15 @@ import sys
 import os
 
 import wx
-import wx.lib.hyperlink as hl
+
+try:
+    import wx.lib.agw.hyperlink as hl
+    import wx.lib.agw.foldpanelbar as fpb
+except ImportError:
+    import wx.lib.hyperlink as hl
+    import wx.lib.foldpanelbar as fpb
+
 from wx.lib.pubsub import pub as Publisher
-import wx.lib.foldpanelbar as fpb
 import wx.lib.colourselect as csel
 
 import invesalius.constants as const
@@ -96,6 +102,7 @@ class InnerTaskPanel(wx.Panel):
         link_new_surface.UpdateLink()
         link_new_surface.Bind(hl.EVT_HYPERLINK_LEFT, self.OnLinkNewSurface)
 
+        Publisher.subscribe(self.OnLinkNewSurface, 'Open create surface dialog')
         # Create horizontal sizers to represent lines in the panel
         line_new = wx.BoxSizer(wx.HORIZONTAL)
         line_new.Add(link_new_surface, 1, wx.EXPAND|wx.GROW| wx.TOP|wx.RIGHT, 4)
@@ -135,8 +142,22 @@ class InnerTaskPanel(wx.Panel):
             evt.Skip()
 
     def OnLinkNewSurface(self, evt=None):
+        
+        is_pubsub = True
+
+        try:
+            evt = evt.data
+            evt = None
+        except:
+            pass
+        
         #import invesalius.gui.dialogs as dlg
         sl = slice_.Slice()
+
+        if sl.current_mask == None:
+            dlg.InexistentMask()
+            return
+
         dialog = dlg.SurfaceCreationDialog(None, -1,
                             _('New surface'),
                             mask_edited=sl.current_mask.was_edited)
@@ -172,7 +193,8 @@ class InnerTaskPanel(wx.Panel):
 
             surface_options = dialog.GetValue()
 
-            Publisher.sendMessage('Create surface from index', surface_options)
+            Publisher.sendMessage('Create surface from index',
+                                  surface_parameters=surface_options)
         dialog.Destroy()
         if evt:
             evt.Skip()
@@ -195,7 +217,10 @@ class FoldPanel(wx.Panel):
 class InnerFoldPanel(wx.Panel):
     def __init__(self, parent):
         wx.Panel.__init__(self, parent)
-        default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
+        try:
+            default_colour = wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENUBAR)
+        except AttributeError:
+            default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
         self.SetBackgroundColour(default_colour)
 
         # Fold panel and its style settings
@@ -264,7 +289,10 @@ BTN_SEEDS = wx.NewId()
 class SurfaceTools(wx.Panel):
     def __init__(self, parent):
         wx.Panel.__init__(self, parent)
-        default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
+        try:
+            default_colour = wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENUBAR)
+        except AttributeError:
+            default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
         self.SetBackgroundColour(default_colour)
 
         #self.SetBackgroundColour(wx.Colour(255,255,255))
@@ -395,13 +423,13 @@ class SurfaceTools(wx.Panel):
             self.EndSeeding()
 
     def StartSeeding(self):
-        print "Start Seeding"
-        Publisher.sendMessage('Enable style', const.VOLUME_STATE_SEED)
+        print("Start Seeding")
+        Publisher.sendMessage('Enable style', style=const.VOLUME_STATE_SEED)
         Publisher.sendMessage('Create surface by seeding - start')
 
     def EndSeeding(self):
-        print "End Seeding"
-        Publisher.sendMessage('Disable style', const.VOLUME_STATE_SEED)
+        print("End Seeding")
+        Publisher.sendMessage('Disable style', style=const.VOLUME_STATE_SEED)
         Publisher.sendMessage('Create surface by seeding - end')
 
 
@@ -409,7 +437,10 @@ class SurfaceTools(wx.Panel):
 class SurfaceProperties(wx.Panel):
     def __init__(self, parent):
         wx.Panel.__init__(self, parent)
-        default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
+        try:
+            default_colour = wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENUBAR)
+        except AttributeError:
+            default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
         self.SetBackgroundColour(default_colour)
 
         self.surface_list = []
@@ -484,8 +515,7 @@ class SurfaceProperties(wx.Panel):
         Publisher.subscribe(self.OnRemoveSurfaces, 'Remove surfaces')
 
 
-    def OnRemoveSurfaces(self, pubsub_evt):
-        list_index = pubsub_evt.data
+    def OnRemoveSurfaces(self, surface_indexes):
         s = self.combo_surface_name.GetSelection()
         ns = 0
 
@@ -493,7 +523,7 @@ class SurfaceProperties(wx.Panel):
         new_dict = []
         i = 0
         for n, (name, index) in enumerate(old_dict):
-            if n not in list_index:
+            if n not in surface_indexes:
                 new_dict.append([name, i])
                 if s == n:
                     ns = i
@@ -505,25 +535,23 @@ class SurfaceProperties(wx.Panel):
         if self.surface_list:
             self.combo_surface_name.SetSelection(ns)
 
-    def OnCloseProject(self, pubsub_evt):
+    def OnCloseProject(self):
         self.CloseProject()
 
     def CloseProject(self):
         n = self.combo_surface_name.GetCount()
-        for i in xrange(n-1, -1, -1):
+        for i in range(n-1, -1, -1):
             self.combo_surface_name.Delete(i)
         self.surface_list = []
 
-    def ChangeSurfaceName(self, pubsub_evt):
-        index, name = pubsub_evt.data
+    def ChangeSurfaceName(self, index, name):
         self.surface_list[index][0] = name
         self.combo_surface_name.SetString(index, name)
 
-    def InsertNewSurface(self, pubsub_evt):
-        #not_update = len(pubsub_evt.data) == 5
-        index = pubsub_evt.data[0]
-        name = pubsub_evt.data[1]
-        colour = [value*255 for value in pubsub_evt.data[2]]
+    def InsertNewSurface(self, surface):
+        index = surface.index
+        name = surface.name
+        colour = [value*255 for value in surface.colour]
         i = 0
         try:
             i = self.surface_list.index([name, index])
@@ -539,21 +567,21 @@ class SurfaceProperties(wx.Panel):
 
         self.combo_surface_name.SetItems([n[0] for n in self.surface_list])
         self.combo_surface_name.SetSelection(i)
-        transparency = 100*pubsub_evt.data[5]
+        transparency = 100*surface.transparency
         self.button_colour.SetColour(colour)
         self.slider_transparency.SetValue(transparency)
-        Publisher.sendMessage('Update surface data', (index))
+        #  Publisher.sendMessage('Update surface data', (index))
 
     def OnComboName(self, evt):
         surface_name = evt.GetString()
         surface_index = evt.GetSelection()
-        Publisher.sendMessage('Change surface selected', self.surface_list[surface_index][1])
+        Publisher.sendMessage('Change surface selected', surface_index=self.surface_list[surface_index][1])
 
     def OnSelectColour(self, evt):
         colour = [value/255.0 for value in evt.GetValue()]
         Publisher.sendMessage('Set surface colour',
-                                    (self.combo_surface_name.GetSelection(),
-                                    colour))
+                              surface_index=self.combo_surface_name.GetSelection(),
+                              colour=colour)
 
     def OnTransparency(self, evt):
         transparency = evt.GetInt()/float(MAX_TRANSPARENCY)
@@ -563,15 +591,18 @@ class SurfaceProperties(wx.Panel):
         if (wx.Platform == "__WXMAC__"):
             transparency = evt.GetInt()/(0.96*float(MAX_TRANSPARENCY))
         Publisher.sendMessage('Set surface transparency',
-                                  (self.combo_surface_name.GetSelection(),
-                                  transparency))
+                              surface_index=self.combo_surface_name.GetSelection(),
+                              transparency=transparency)
 
 
 class QualityAdjustment(wx.Panel):
     def __init__(self, parent):
         import invesalius.constants as const
         wx.Panel.__init__(self, parent)
-        default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
+        try:
+            default_colour = wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENUBAR)
+        except AttributeError:
+            default_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_MENUBAR)
         self.SetBackgroundColour(default_colour)
 
         # LINE 1
@@ -627,7 +658,7 @@ class QualityAdjustment(wx.Panel):
         self.SetAutoLayout(1)
 
     def OnComboQuality(self, evt):
-        print "TODO: Send Signal - Change surface quality: %s" % (evt.GetString())
+        print("TODO: Send Signal - Change surface quality: %s" % (evt.GetString()))
 
     def OnDecimate(self, evt):
-        print "TODO: Send Signal - Decimate: %s" % float(self.spin.GetValue())/100
+        print("TODO: Send Signal - Decimate: %s" % float(self.spin.GetValue())/100)
