@@ -97,8 +97,8 @@ class Button(object):
         """
         Test if the button was clicked.
         """
-        print self.position
-        print self.size
+        print(self.position)
+        print(self.size)
         m_x, m_y = position
         i_x, i_y = self.position
         w, h = self.size
@@ -146,7 +146,7 @@ class CLUTRaycastingWidget(wx.Panel):
         Se the range from hounsfield
         """
         self.init, self.end = range
-        print "Range", range
+        print("Range", range)
         self.CalculatePixelPoints()
 
     def SetPadding(self, padding):
@@ -169,12 +169,12 @@ class CLUTRaycastingWidget(wx.Panel):
         pass
 
     def OnClick(self, evt):
-        x, y = evt.GetPositionTuple()
-        if self.save_button.HasClicked(evt.GetPositionTuple()):
-            print "Salvando"
+        x, y = evt.GetPosition()
+        if self.save_button.HasClicked((x, y)):
+            print("Salvando")
             filename = dialog.ShowSavePresetDialog()
             if filename:
-                Publisher.sendMessage('Save raycasting preset', filename)
+                Publisher.sendMessage('Save raycasting preset', preset_name=filename)
         point = self._has_clicked_in_a_point((x, y))
         # A point has been selected. It can be dragged.
         if point:
@@ -218,7 +218,7 @@ class CLUTRaycastingWidget(wx.Panel):
         """
         Used to change the colour of a point
         """
-        point = self._has_clicked_in_a_point(evt.GetPositionTuple())
+        point = self._has_clicked_in_a_point(evt.GetPosition())
         if point:
             i, j = point
             actual_colour = self.curves[i].nodes[j].colour
@@ -240,18 +240,18 @@ class CLUTRaycastingWidget(wx.Panel):
         """
         Used to remove a point
         """
-        point = self._has_clicked_in_a_point(evt.GetPositionTuple())
+        point = self._has_clicked_in_a_point(evt.GetPosition())
         if point:
             i, j = point
-            print "RightClick", i, j
+            print("RightClick", i, j)
             self.RemovePoint(i, j)
             self.Refresh()
             nevt = CLUTEvent(myEVT_CLUT_POINT_RELEASE, self.GetId(), i)
             self.GetEventHandler().ProcessEvent(nevt)
             return
-        n_curve = self._has_clicked_in_selection_curve(evt.GetPositionTuple())
+        n_curve = self._has_clicked_in_selection_curve(evt.GetPosition())
         if n_curve is not None:
-            print "Removing a curve"
+            print("Removing a curve")
             self.RemoveCurve(n_curve)
             self.Refresh()
             nevt = CLUTEvent(myEVT_CLUT_POINT_RELEASE, self.GetId(), n_curve)
@@ -280,7 +280,7 @@ class CLUTRaycastingWidget(wx.Panel):
         direction = evt.GetWheelRotation() / evt.GetWheelDelta()
         init = self.init - RANGE * direction
         end = self.end + RANGE * direction
-        print direction, init, end
+        print(direction, init, end)
         self.SetRange((init, end))
         self.Refresh()
 
@@ -369,7 +369,7 @@ class CLUTRaycastingWidget(wx.Panel):
 
     def _has_clicked_in_save(self, clicked_point):
         x, y = clicked_point
-        print x, y
+        print(x, y)
         if self.padding < x < self.padding + 24 and \
            self.padding < y < self.padding + 24:
             return True
@@ -559,7 +559,7 @@ class CLUTRaycastingWidget(wx.Panel):
     def _draw_histogram(self, ctx, height):
         # The histogram
         x,y = self.Histogram.points[0]
-        print "=>", x,y
+        print("=>", x,y)
 
         ctx.SetPen(wx.Pen(HISTOGRAM_LINE_COLOUR, HISTOGRAM_LINE_WIDTH))
         ctx.SetBrush(wx.Brush(HISTOGRAM_FILL_COLOUR))
@@ -567,7 +567,7 @@ class CLUTRaycastingWidget(wx.Panel):
         path = ctx.CreatePath()
         path.MoveToPoint(x,y)
         for x,y in self.Histogram.points:
-            print x,y
+            print(x,y)
             path.AddLineToPoint(x, y)
 
         ctx.PushState()
@@ -624,7 +624,7 @@ class CLUTRaycastingWidget(wx.Panel):
         proportion_x = width * 1.0 / (x_end - x_init)
         proportion_y = height * 1.0 / (y_end - y_init)
         self.Histogram.points = []
-        for i in xrange(0, len(self.histogram_array), 5):
+        for i in range(0, len(self.histogram_array), 5):
             if self.histogram_array[i]:
                 y = math.log(self.histogram_array[i])
             else:
@@ -649,7 +649,7 @@ class CLUTRaycastingWidget(wx.Panel):
         """
         for n, (point, colour) in enumerate(zip(self.points, self.colours)):
             point_colour = zip(point, colour)
-            point_colour.sort(key=lambda x: x[0]['x'])
+            point_colour = sorted(point_colour, key=lambda x: x[0]['x'])
             self.points[n] = [i[0] for i in point_colour]
             self.colours[n] = [i[1] for i in point_colour]
 
