@@ -121,8 +121,11 @@ class GradientSlider(wx.Panel):
         dc.GradientFillLinear((x_init_gradient, y_init_gradient,
                                width_gradient, height_gradient),
                               (0, 0, 0), (255,255, 255))
-        
-        n = wx.RendererNative_Get()
+
+        try:
+            n = wx.RendererNative.Get()
+        except AttributeError:
+            n = wx.RendererNative_Get()
 
         # Drawing the push buttons
         n.DrawPushButton(self, dc, (x_init_push1, 0, PUSH_WIDTH, h))
@@ -327,7 +330,7 @@ class GradientCtrl(wx.Panel):
         self.max_range = maxRange
         self.minimun = minValue
         self.maximun = maxValue
-        self.colour = colour
+        self.colour = colour[:3]
         self.changed = False
         self._draw_controls()
         self._bind_events_wx()
@@ -433,7 +436,7 @@ class GradientCtrl(wx.Panel):
         self._GenerateEvent(myEVT_THRESHOLD_CHANGING)
 
     def SetColour(self, colour):
-        colour = list(colour) + [90,]
+        colour = list(colour[:3]) + [90,]
         self.colour = colour
         self.gradient_slider.SetColour(colour)
         self.gradient_slider.Refresh()
